==> cscec5b-fbxt-api-3.0.1-20211203.042743-20-sources.jar: com/ejianc/business/fbxt/grap/vo/AssignmrnyBookVO.java <==
package com.ejianc.business.fbxt.grap.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


public class AssignmrnyBookVO extends BaseVO {

    //任务书主键
    private String pkAssignmentBook;
    //项目名称
    private String projectName;
 /*   //总包单位
    private String assUnit;*/
    //合同名称
    private String contractName;
    //施工部位
    private String construction;
    //编制人
    private String pkCreator;
    //编制时间  timestamp
    private Date creatorTime;
    //单据状态  -1：暂存 0：待确认 1：已确认 2：存疑退回
    private Integer billState;
    //进度说明
    private String memo;
    //供应商主键
    private String pkSupplier;
    //进度照片URL
    private String imgPath;
    //项目主键
    private String pkProject;
    // 合同主键
    private String pkContract;
    //编制人
    private String creatorName;
    //修改人
    private String pkModified;
    //单据编号
    private String billCode;
    //修改日期
    private String modifiedDate;
    //存疑退回意见
    private String feedback;
    //供应商名称
    private String supplierName;
    //确认人主键
    private String confirmer;
    //确认人姓名
    private String confirmerName;
    //确认时间
    private String confirmerData;
    //汇总子表金额
    private BigDecimal sumMany;
    //组织主键
    private String pkOrg;
    //合同编码
    private String contractCode;

    //子表
    private List<AssignmentInfoVO> assInfoList = new ArrayList<>();

    //图片信息
    private List<FileVO> fileList = new ArrayList<>();

    public List<FileVO> getFileList() {
        return fileList;
    }

    public void setFileList(List<FileVO> fileList) {
        this.fileList = fileList;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getConfirmer() {
        return confirmer;
    }

    public void setConfirmer(String confirmer) {
        this.confirmer = confirmer;
    }

    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }

    public String getConfirmerData() {
        return confirmerData;
    }

    public void setConfirmerData(String confirmerData) {
        this.confirmerData = confirmerData;
    }

    public BigDecimal getSumMany() {
        return sumMany;
    }

    public void setSumMany(BigDecimal sumMany) {
        this.sumMany = sumMany;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getPkModified() {
        return pkModified;
    }

    public void setPkModified(String pkModified) {
        this.pkModified = pkModified;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(String modifiedDate) {
        this.modifiedDate = modifiedDate;
    }



    public String getPkAssignmentBook() {
        return pkAssignmentBook;
    }

    public void setPkAssignmentBook(String pkAssignmentBook) {
        this.pkAssignmentBook = pkAssignmentBook;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }


    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public Date getCreatorTime() {
        return creatorTime;
    }

    public void setCreatorTime(Date creatorTime) {
        this.creatorTime = creatorTime;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getImgPath() {
        return imgPath;
    }

    public void setImgPath(String imgPath) {
        this.imgPath = imgPath;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public List<AssignmentInfoVO> getAssInfoList() {
        return assInfoList;
    }

    public void setAssInfoList(List<AssignmentInfoVO> assInfoList) {
        this.assInfoList = assInfoList;
    }
}

==> cscec5b-fbxt-api-3.0.1-20240306.013724-187-sources.jar: com/ejianc/business/fbxt/grap/vo/AssignmrnyBookVO.java <==
package com.ejianc.business.fbxt.grap.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


public class AssignmrnyBookVO extends BaseVO {

    //任务书主键
    private String pkAssignmentBook;
    //项目名称
    private String projectName;
 /*   //总包单位
    private String assUnit;*/
    //合同名称
    private String contractName;
    //施工部位
    private String construction;
    //编制人
    private String pkCreator;
    //编制时间  timestamp
    private String creatorTime;
    //单据状态  -1：暂存 0：待确认 1：已确认 2：存疑退回
    private Integer billState;
    //进度说明
    private String memo;
    //供应商主键
    private String pkSupplier;
    //进度照片URL
    private String imgPath;
    //项目主键
    private String pkProject;
    // 合同主键
    private String pkContract;
    //编制人
    private String creatorName;
    //修改人
    private String pkModified;
    //单据编号
    private String billCode;
    //修改日期
    private String modifiedDate;
    //存疑退回意见
    private String feedback;
    //供应商名称
    private String supplierName;
    //确认人主键
    private String confirmer;
    //确认人姓名
    private String confirmerName;
    //确认时间
    private String confirmerData;
    //汇总子表金额
    private BigDecimal sumMany;
    //组织主键
    private String pkOrg;
    //合同编码
    private String contractCode;

    //子表
    private List<AssignmentInfoVO> assInfoList = new ArrayList<>();

    //图片信息
    private List<FileVO> fileList = new ArrayList<>();

    public List<FileVO> getFileList() {
        return fileList;
    }

    public void setFileList(List<FileVO> fileList) {
        this.fileList = fileList;
    }

    public String getContractCode() {
        return contractCode;
    }

    public void setContractCode(String contractCode) {
        this.contractCode = contractCode;
    }

    public String getConfirmer() {
        return confirmer;
    }

    public void setConfirmer(String confirmer) {
        this.confirmer = confirmer;
    }

    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }

    public String getConfirmerData() {
        return confirmerData;
    }

    public void setConfirmerData(String confirmerData) {
        this.confirmerData = confirmerData;
    }

    public BigDecimal getSumMany() {
        return sumMany;
    }

    public void setSumMany(BigDecimal sumMany) {
        this.sumMany = sumMany;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getFeedback() {
        return feedback;
    }

    public void setFeedback(String feedback) {
        this.feedback = feedback;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getPkModified() {
        return pkModified;
    }

    public void setPkModified(String pkModified) {
        this.pkModified = pkModified;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public String getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(String modifiedDate) {
        this.modifiedDate = modifiedDate;
    }



    public String getPkAssignmentBook() {
        return pkAssignmentBook;
    }

    public void setPkAssignmentBook(String pkAssignmentBook) {
        this.pkAssignmentBook = pkAssignmentBook;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }


    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }

    public String getConstruction() {
        return construction;
    }

    public void setConstruction(String construction) {
        this.construction = construction;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorTime() {
        return creatorTime;
    }

    public void setCreatorTime(String creatorTime) {
        this.creatorTime = creatorTime;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getImgPath() {
        return imgPath;
    }

    public void setImgPath(String imgPath) {
        this.imgPath = imgPath;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public List<AssignmentInfoVO> getAssInfoList() {
        return assInfoList;
    }

    public void setAssInfoList(List<AssignmentInfoVO> assInfoList) {
        this.assInfoList = assInfoList;
    }
}
